bbprep.selectors.AllSelector
============================

.. currentmodule:: bbprep.selectors

.. autoclass:: AllSelector
   :members:

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~AllSelector.select_atoms
   
   

   
   
   